@@ -26,10 +26,9 @@
 #include "sonnetui_export.h"
 
 class QTextEdit;
+class QPlainTextEdit;
 
-namespace Sonnet
-{
-
+namespace Sonnet {
 class Highlighter;
 
 /**
@@ -49,6 +48,14 @@ public:
      */
     explicit SpellCheckDecorator(QTextEdit *textEdit);
 
+    /**
+     * Creates a spell-check decorator.
+     *
+     * @param textEdit the QPlainTextEdit in need of spell-checking. It also is used as the QObject parent for the decorator.
+     * @since 5.12
+     */
+    explicit SpellCheckDecorator(QPlainTextEdit *textEdit);
+
     ~SpellCheckDecorator();
 
     /**
@@ -78,7 +85,6 @@ private:
     Private *const d;
     Q_DISABLE_COPY(SpellCheckDecorator)
 };
-
 }
 
 #endif /* SPELLCHECKDECORATOR_H */
